﻿using System;
using System.ComponentModel;
using System.Windows.Input;
using Comm.Wcf.Client;
using Microsoft.Practices.Prism.Commands;

namespace Client.ViewModel
{
    public class MainViewModel : INotifyPropertyChanged
    {
        #region Fields

        private readonly CServiceThread _serviceThread = CServiceThread.GetInstance();
        private ICommand _commandRequestHelloWorld;
        private String _helloWorld;

        #endregion

        #region Properties

        public ICommand CommandRequestHelloWorld
        {
            get
            {
                if (_commandRequestHelloWorld == null)
                {
                    _commandRequestHelloWorld =
                        new DelegateCommand(() => { _serviceThread.Service.RequestHelloWorld(); });
                }

                return _commandRequestHelloWorld;
            }
        }

        public String HelloWorld
        {
            get { return _helloWorld; }
            set
            {
                _helloWorld = value;
                NotifyPropertyChanged("HelloWorld");
            }
        }

        #endregion

        #region Constructor/Destructors

        public MainViewModel()
        {
            _serviceThread.Service.OnUpdateHelloWorld += Service_OnUpdateHelloWorld;
            _serviceThread.ServiceActive = true;
        }

        #endregion

        #region Methods

        private void NotifyPropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }

        #endregion

        #region Event Handling

        private void Service_OnUpdateHelloWorld(object sender, EventArgs e)
        {
            HelloWorld = _serviceThread.Service.HelloWorld;
        }

        #endregion

        #region INotifyPropertyChanged Members

        public event PropertyChangedEventHandler PropertyChanged;

        #endregion
    }
}