﻿using System;
using Comm.Wcf.Interfaces;

namespace Comm.Wcf.Client
{
    /// <summary>
    ///   Callback class for CData channel
    /// </summary>
    public class CDataCallback : IDataCallback
    {
        #region Event Declarations

        /// <summary>
        ///   Event handler which will be thrown, when SetAliveRoundTrip from server was called
        /// </summary>
        public event EventHandler OnAliveRoundTrip;

        /// <summary>
        ///   Event handler which will be thrown, when UpdateHelloWorld from server was called
        /// </summary>
        public event EventHandler OnUpdateHelloWorld;

        #endregion

        #region Fields

        private String _helloWorld = String.Empty;

        #endregion

        #region Properties

        /// <summary>
        ///   Hello world content
        /// </summary>
        public String HelloWorld
        {
            get { return _helloWorld; }
        }

        #endregion

        #region IDataCallback Members

        /// <summary>
        ///   This method will be called from the server side, when a client has requested a round trip. This round trip will be used for the communication watchdog to detect if the channel is still alive.
        /// </summary>
        public void SetAliveRoundTrip()
        {
            if (OnAliveRoundTrip != null)
            {
                OnAliveRoundTrip(this, new EventArgs());
            }
        }

        /// <summary>
        ///   This method will be called from the server side. The HelloWorld content will be transmitted
        /// </summary>
        /// <param name="helloWorld"> Hello world content </param>
        public void UpdateHelloWorld(String helloWorld)
        {
            _helloWorld = helloWorld;

            if (OnUpdateHelloWorld != null)
            {
                OnUpdateHelloWorld(this, new EventArgs());
            }
        }

        #endregion
    }
}