﻿using System;
using System.Runtime.Serialization;
using System.Timers;
using Comm.Wcf.Interfaces;

namespace Comm.Wcf.Utils
{
    /// <summary>
    ///   Subscriber class
    /// </summary>
    public class CSubscriber : IDisposable
    {
        #region Event Declarations

        /// <summary>
        ///   Event when connection timeout occurs
        /// </summary>
        public event EventHandler Timeout;

        #endregion

        #region Fields

        private readonly Timer _connectionWatchdogTimer = new Timer();

        /// <summary>
        ///   Unique identification number of the subscriber
        /// </summary>
        [DataMember] public Guid Id;

        #endregion

        #region Properties

        /// <summary>
        ///   Callback channel
        /// </summary>
        public IDataCallback Callback { get; set; }

        #endregion

        #region Constructor/Destructors

        /// <summary>
        ///   Constructor for CSubscriber
        /// </summary>
        public CSubscriber()
        {
            _connectionWatchdogTimer.Elapsed += ConnectionWatchdogTimerElapsed;
            _connectionWatchdogTimer.Interval = 20000;
            _connectionWatchdogTimer.Enabled = true;
        }

        #endregion

        #region Methods

        /// <summary>
        ///   Reset connection watchdog timer
        /// </summary>
        public void RefreshTimeout()
        {
            _connectionWatchdogTimer.Enabled = false;
            _connectionWatchdogTimer.Enabled = true;
        }

        #endregion

        #region Event Handling

        private void ConnectionWatchdogTimerElapsed(object sender, ElapsedEventArgs e)
        {
            _connectionWatchdogTimer.Enabled = false;
            _connectionWatchdogTimer.Elapsed -= ConnectionWatchdogTimerElapsed;
            if (Timeout != null)
            {
                Timeout(this, new EventArgs());
            }
        }

        #endregion

        #region IDisposable Members

        /// <summary>
        ///   Dispose
        /// </summary>
        public void Dispose()
        {
            _connectionWatchdogTimer.Elapsed -= ConnectionWatchdogTimerElapsed;
        }

        #endregion
    }
}