﻿using System;
using System.Collections.ObjectModel;
using System.ServiceModel;
using Comm.Wcf.Server;
using Server.Model;

namespace Server.ViewModel
{
    public class MainViewModel
    {
        #region Fields

        private readonly ServiceHost _host;

        private readonly ObservableCollection<CLogItem> _logItemList =
            new ObservableCollection<CLogItem>();

        private readonly Type _serviceType = typeof (CServiceServer);

        #endregion

        #region Properties

        public ObservableCollection<CLogItem> LogItemList
        {
            get { return _logItemList; }
        }

        #endregion

        #region Constructor/Destructors

        public MainViewModel()
        {
            _host = new ServiceHost(_serviceType);
            _host.Closed += HostClosed;
            _host.Closing += HostClosing;
            _host.Faulted += HostFaulted;
            _host.Opened += HostOpened;
            _host.Opening += HostOpening;
            _host.UnknownMessageReceived += HostUnknownMessageReceived;
            _host.Open();
        }

        #endregion

        #region Methods

        private void LogMessage(string logMessage)
        {
            _logItemList.Add(new CLogItem(logMessage));

            if (_logItemList.Count > 10)
            {
                CLogItem logItem = _logItemList[0];
                _logItemList.Remove(logItem);
            }
        }

        #endregion

        #region Event Handling

        private void HostClosed(object sender, EventArgs e)
        {
            LogMessage("HostClosed");
        }

        private void HostClosing(object sender, EventArgs e)
        {
            LogMessage("HostClosing");
        }

        private void HostFaulted(object sender, EventArgs e)
        {
            LogMessage("HostFaulted");
        }

        private void HostOpened(object sender, EventArgs e)
        {
            LogMessage("HostOpened");
        }

        private void HostOpening(object sender, EventArgs e)
        {
            LogMessage("HostOpening");
        }

        private void HostUnknownMessageReceived(object sender, UnknownMessageReceivedEventArgs e)
        {
            LogMessage("HostUnknownMessageReceived");
        }

        #endregion
    }
}